Module: Crown

Defined in:
lib/crown/cgm.rb,
lib/crown.rb,
lib/crown/topsy.rb,
lib/crown/yahoo.rb,
lib/crown/amazon.rb,
lib/crown/google.rb,
lib/crown/buzzurl.rb,
lib/crown/twitter.rb,
lib/crown/backtype.rb,
lib/crown/facebook.rb,
lib/crown/linkedin.rb,
lib/crown/delicious.rb,
lib/crown/tweetmeme.rb,
lib/crown/twitter/uri.rb,
lib/crown/http-wrapper.rb,
lib/crown/twitter/user.rb,
lib/crown/cgm/countable.rb,
lib/crown/livedoor/clip.rb,
lib/crown/topsy/counter.rb,
lib/crown/amazon/crawler.rb,
lib/crown/facebook/entry.rb,
lib/crown/google/plusone.rb,
lib/crown/yahoo/bookmark.rb,
lib/crown/buzzurl/counter.rb,
lib/crown/hatena/bookmark.rb,
lib/crown/livedoor/reader.rb,
lib/crown/amazon/entrylist.rb,
lib/crown/backtype/counter.rb,
lib/crown/facebook/counter.rb,
lib/crown/linkedin/counter.rb,
lib/crown/delicious/counter.rb,
lib/crown/tweetmeme/counter.rb,
lib/crown/twitter/uri/counter.rb,
lib/crown/google/plusone/counter.rb,
lib/crown/yahoo/bookmark/counter.rb,
lib/crown/hatena/bookmark/urilist.rb,
lib/crown/hatena/bookmark/entrylist.rb

Overview

--------------------------------------------------------------------------- #

hatena/bookmark/entrylist.rb

Copyright (c) 2008 - 2012, clown.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:

- Redistributions of source code must retain the above copyright
 notice, this list of conditions and the following disclaimer.
- Redistributions in binary form must reproduce the above copyright
 notice, this list of conditions and the following disclaimer in the
 documentation and/or other materials provided with the distribution.
- No names of its contributors may be used to endorse or promote
 products derived from this software without specific prior written
 permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

--------------------------------------------------------------------------- #

Defined Under Namespace

Modules: Amazon, CGM, Google, Hatena, Livedoor, Twitter, Yahoo Classes: BackType, Buzzurl, Delicious, Facebook, FacebookCounter, FacebookEntry, HTTPWrapper, LinkedIn, Topsy, TweetMeme

Constant Summary collapse

VERSION =
'0.1.1'